@@ -5,6 +5,8 @@ use warnings;
 
 use base 'Devel::hdb::App::Breakpoint';
 
+our $VERSION = '0.24';
+
 sub response_url_base() { '/actions' }
 
 __PACKAGE__->add_route('post', response_url_base(), 'set');
@@ -96,7 +98,7 @@ Returns 404 if there is no action with that id.
 
 =head1 SEE ALSO
 
-Devel::hdb
+L<Devel::hdb>
 
 =head1 AUTHOR
 
@@ -104,5 +106,5 @@ Anthony Brummett <brummett@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2014, Anthony Brummett.  This module is free software. It may
+Copyright 2018, Anthony Brummett.  This module is free software. It may
 be used, redistributed and/or modified under the same terms as Perl itself.
