@@ -9,6 +9,8 @@ use Plack::Request;
 use Digest::MD5 qw();
 use Time::HiRes qw();
 
+our $VERSION = '0.24';
+
 sub response_url_base() { '/breakpoints' };
 
 __PACKAGE__->add_route('post', response_url_base(), 'set');
@@ -311,7 +313,7 @@ Returns 404 if there is no breakpoint with that id.
 
 =head1 SEE ALSO
 
-Devel::hdb
+L<Devel::hdb>
 
 =head1 AUTHOR
 
@@ -319,5 +321,5 @@ Anthony Brummett <brummett@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2014, Anthony Brummett.  This module is free software. It may
+Copyright 2018, Anthony Brummett.  This module is free software. It may
 be used, redistributed and/or modified under the same terms as Perl itself.
