@@ -5,6 +5,8 @@ use warnings;
 
 use base 'Devel::hdb::App::Base';
 
+our $VERSION = '0.24';
+
 __PACKAGE__->add_route('post', qr{/loadconfig/(.+)}, \&loadconfig);
 __PACKAGE__->add_route('post', qr{/saveconfig/(.+)}, \&saveconfig);
 
@@ -66,7 +68,7 @@ line-actions are restored.
 
 =head1 SEE ALSO
 
-Devel::hdb
+L<Devel::hdb>
 
 =head1 AUTHOR
 
@@ -74,5 +76,5 @@ Anthony Brummett <brummett@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2014, Anthony Brummett.  This module is free software. It may
+Copyright 2018, Anthony Brummett.  This module is free software. It may
 be used, redistributed and/or modified under the same terms as Perl itself.
