@@ -7,6 +7,8 @@ use base 'Devel::hdb::App::Base';
 
 use URI::Escape;
 
+our $VERSION = '0.24';
+
 __PACKAGE__->add_route('get', '/', \&overview);
 __PACKAGE__->add_route('get', '/program_name', \&program_name);
 
@@ -85,7 +87,7 @@ Returns 200 and a JSON-encoded hash with one key:
 
 =head1 SEE ALSO
 
-Devel::hdb
+L<Devel::hdb>
 
 =head1 AUTHOR
 
@@ -93,5 +95,5 @@ Anthony Brummett <brummett@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2014, Anthony Brummett.  This module is free software. It may
+Copyright 2018, Anthony Brummett.  This module is free software. It may
 be used, redistributed and/or modified under the same terms as Perl itself.
