@@ -7,6 +7,8 @@ use base 'Devel::hdb::App::Base';
 
 use URI::Escape;
 
+our $VERSION = '0.24';
+
 __PACKAGE__->add_route('get', qr{/source/(.+)}, \&sourcefile);
 __PACKAGE__->add_route('get', qr{(/source)}, \&loaded_files);
 
@@ -88,7 +90,7 @@ line is not breakable, and true if it is.
 
 =head1 SEE ALSO
 
-Devel::hdb
+L<Devel::hdb>
 
 =head1 AUTHOR
 
@@ -96,5 +98,5 @@ Anthony Brummett <brummett@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2014, Anthony Brummett.  This module is free software. It may
+Copyright 2018, Anthony Brummett.  This module is free software. It may
 be used, redistributed and/or modified under the same terms as Perl itself.
