@@ -15,6 +15,8 @@ our @EXPORT_OK = qw(_serialize_stack);
 
 use Data::Transform::ExplicitMetadata qw(encode);
 
+our $VERSION = '0.24';
+
 __PACKAGE__->add_route('get', qr{(^/stack$)}, \&stack);
 __PACKAGE__->add_route('head', qr{^/stack$}, \&stack_head);
 __PACKAGE__->add_route('get', qr{(^/stack)/(\d+)$}, \&stack_frame);
@@ -184,7 +186,7 @@ there is no frame as deep as was requested.
 
 =head1 SEE ALSO
 
-Devel::hdb, Data::Transform::ExplicitMetadata
+L<Devel::hdb>, L<Data::Transform::ExplicitMetadata>
 
 =head1 AUTHOR
 
@@ -192,5 +194,5 @@ Anthony Brummett <brummett@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2014, Anthony Brummett.  This module is free software. It may
+Copyright 2018, Anthony Brummett.  This module is free software. It may
 be used, redistributed and/or modified under the same terms as Perl itself.
