@@ -26,6 +26,7 @@ function Debugger(sel) {
         breakpointRightClickMenu: Handlebars.compile( $('#breakpoint-right-click-template').html() ),
         saveLoadBreakpointsModal: Handlebars.compile($('#save-load-breakpoints-modal-template').html() ),
         subPickerTemplate: Handlebars.compile($('#sub-picker-template').html() ),
+        quickBreakpointModal: Handlebars.compile($('#quick-breakpoint-entry-template').html() ),
     };
 
     // The step in, over, run buttons
@@ -526,14 +527,229 @@ function Debugger(sel) {
                     $('#breakpoint-container-handle').click();
                     e.stopPropagation();
                     break;
-                case 98: //b
+                case 66: //B
                     dbg.stackDiv.find('.tab-pane.active .code-line.active span.lineno').click();
                     e.stopPropagation();
                     break;
+                case 98: //b
+                    dbg.quickBreakpointDialog();
+                    e.stopPropagation();
+                    break;
             }
         });
     }
 
+    var quick_bp_dialog_open = false;
+    this.quickBreakpointDialog = function() {
+        if (quick_bp_dialog_open) {
+            return;
+        }
+        quick_bp_dialog_open = true;
+
+        var modal = $(this.templates.quickBreakpointModal());
+
+        modal.appendTo($elt)
+            .modal({ backdrop: true, keyboard: true, show: true })
+            .on('hidden', function() {
+                quick_bp_dialog_open = false;
+                modal.remove();
+            })
+            .keyup(function(e) {
+                if (e.keyCode == 27) { // escape - abort editing
+                    modal.modal('hide');
+                    return false;
+                }
+            })
+            .find('input')
+                .focus();
+
+        modal.find('form')
+            .submit(function(e) {
+                    e.preventDefault();
+                    var bp_text = $(e.target).find('[name=breakpoint]').val();
+
+                    parseQuickBreakpointText(bp_text)
+                        .done(function(filename, line) {
+                            dbg.breakpointManager.createBreakpoint({filename: filename, line: line});
+                        })
+                        .fail(function(message) {
+                            alert(message);
+                        })
+                        .always(function() {
+                            modal.modal('hide');
+                        });
+            });
+    }
+
+    function QB_isCurrentLine(text) {
+        var d = $.Deferred();
+        if (text.match(/^\.$/)) {  // A single period
+            var current_frameno = $('div#stack-panes .tab-pane.active').attr('data-frameno'),
+                stack_frame = dbg.stackManager.frame(current_frameno);
+            debugger;
+            d.resolve(stack_frame.filename, stack_frame.line);
+        } else {
+            d.reject(undefined);
+        }
+        return d;
+    }
+
+    function QB_isLineNumber(text) {
+        var d = $.Deferred();
+        var matches = text.match(/^\d+$/);  // match only digits - a line number in the current stackframe's file
+        if (matches) {
+            var line = dbg.stackDiv.find('.tab-pane.active .code-line[data-lineno='+text+']');
+            if (line.length == 0) {
+                d.reject('No such line number in the current file');
+            } else if (line.hasClass('unbreakable')) {
+                d.reject('Line ' + text + ' is not breakable');
+            } else {
+                var file = dbg.stackDiv.find('.tab-pane.active .program-code-container').attr('data-filename');
+                d.resolve(file, text);
+            }
+        } else {
+            d.reject(undefined);
+        }
+        return d.promise();
+    }
+
+    function QB_isFQSubroutine(text) {
+        var d = $.Deferred();
+        var matches = text.match(/^(.+?::\w+)(?::(\d+))?$/); // match "package::subname" or "package::subname:line"
+        if (matches) {
+            var subname = matches[1],
+                line = matches[2];
+
+            restInterface.subInfo(subname)
+                    .done(function(data) {
+                        _QB_findBreakableLineInSub(line, d, data);
+                    })
+                    .fail(function() {
+                        d.reject(undefined);
+                    })
+
+        } else {
+            d.reject(undefined);
+        }
+        return d.promise();
+    }
+
+    function QB_isSubroutine(text) {
+        var d = $.Deferred();
+        var matches = text.match(/^(.+?)(?::(\d+))?$/);  // match either "string" or "string:numbers"
+        if (matches) {
+            var subname = matches[1],
+                line = matches[2],
+                current_frameno = $('div#stack-panes .tab-pane.active').attr('data-frameno'),
+                stack_frame = dbg.stackManager.frame(current_frameno),
+                current_package = stack_frame.package;
+
+            restInterface.subInfo(current_package + '::' + subname)
+                        .done(function(data) {
+                            _QB_findBreakableLineInSub(line, d, data);
+                        })
+                        .fail(function(data) {
+                            d.reject(undefined);
+                        });
+        } else {
+            d.reject(undefined);
+        }
+        return d.promise();
+    }
+
+    function _QB_findBreakableLineInSub(requested_line_str, deferred, subinfo_data) {
+        var start_breakable_search,
+            sub_start_line = parseInt(subinfo_data.line, 10),
+            sub_end_line = parseInt(subinfo_data.end, 10),
+            requested_line = parseInt(requested_line_str, 10);
+
+        if (requested_line_str) {  // They wanted to stop on a particular line
+            var sub_length = sub_end_line - sub_start_line;
+            if (requested_line > sub_length) {
+                deferred.reject(requested_line_str + ' is outside the range of sub ' + subinfo_data.subroutine);
+            }
+            start_breakable_search = sub_start_line + requested_line;
+
+            if (dbg.fileManager.isBreakable(subinfo_data.filename, sub_start_line)) {
+                // if the sub's first line is breakable, then line "1" of the sub
+                // is the same as the sub's start line
+                start_breakable_search = start_breakable_search - 1;
+            }
+
+        } else {
+            start_breakable_search = sub_start_line;
+        }
+
+        for(var break_on_line = start_breakable_search; break_on_line < subinfo_data.end; break_on_line++) {
+            if (dbg.fileManager.isBreakable(subinfo_data.filename, break_on_line)) {
+                deferred.resolve(subinfo_data.filename, break_on_line);
+            }
+        }
+        deferred.reject("Couldn't file a breakable line within '"
+                        + subinfo_data.subroutine
+                        + '. Tried line ' + requested_line + ' to the end of the function');
+    }
+
+    function QB_isFile(text) {
+        var d = $.Deferred();
+        var matches = text.match(/^(.+?):(\d+)$/);  // match "string:numbers"
+        if (matches) {
+            var filename = matches[1],
+                line = matches[2];
+            if (dbg.fileManager.isLoaded(filename)) {
+                if (dbg.fileManager.isBreakable(filename, line)) {
+                    d.resolve(filename, line);
+                } else {
+                    d.reject(filename + ':' + line + ' is not breakable');
+                }
+            } else {
+                d.reject(undefined);
+            }
+        } else {
+            d.reject(undefined);
+        }
+        return d.promise();
+    }
+
+    function QB_unparsable(text) {
+        var d = $.Deferred();
+        d.reject("Could not parse breakpoint '" + text + "'");
+        return d.promise();
+    }
+
+    var quick_breakpoint_resolvers = [
+        QB_isCurrentLine,
+        QB_isLineNumber,
+        QB_isFQSubroutine,
+        QB_isSubroutine,
+        QB_isFile,
+        QB_unparsable,
+    ];
+    function parseQuickBreakpointText(text) {
+        var i = 0,
+            d = $.Deferred();
+
+        function tryNextResolver() {
+            var resolver = quick_breakpoint_resolvers[i],
+                p = resolver(text);
+            i++;
+
+            p.done(function(filename, line) {
+                d.resolve(filename, line);  // try just putting d in the done()?
+            })
+            .fail(function(message) {
+                if (message) {
+                    d.reject(message);
+                } else {
+                    tryNextResolver();
+                }
+            })
+        }
+
+        tryNextResolver();
+        return d.promise();
+    }
+                                    
     var $breakpointPane = $('#breakpoint-container'),
         $breakpointToggleIcon = $('#breakpoint-container-handle-icon');
 
