@@ -290,7 +290,10 @@ PerlValue.prototype.refHeaderString = function() {
     if (this.blessed) {
         html += this.blessed + '=';
     }
-    html += this.type + '(0x' + this.refaddr.toString(16) + ')';
+    html += this.type;
+    if (this.refaddr) {
+        html += '(0x' + this.refaddr.toString(16) + ')';
+    }
     return html;
 }
 PerlValue.prototype.renderHeader = function(view) { return '' };
