@@ -50,7 +50,7 @@ function RestInterface(base_url) {
     };
 
     this.fileSourceAndBreakable = function(filename) {
-        return this._GET('source/' + filename, undefined);
+        return this._GET('source/' + encodeURIComponent(filename), undefined);
     };
 
     this.exit = function() {
